from .types import ElementType

class Types:
    div = ElementType("div")
    p = ElementType("p")
    h1 = ElementType("h1")
    h2 = ElementType("h2")
    h3 = ElementType("h3")
    h4 = ElementType("h4")
    h5 = ElementType("h5")
    h6 = ElementType("h6")
    a = ElementType("a")
    button = ElementType("button")